@@ -1,4 +1,4 @@
-# $Id: http.pm,v 1.67 2004/03/10 20:10:18 gisle Exp $
+# $Id: http.pm,v 1.69 2004/12/14 12:38:45 gisle Exp $
 #
 
 package LWP::Protocol::http;
@@ -160,6 +160,7 @@ sub request
 
     $request_headers->scan(sub {
 			       my($k, $v) = @_;
+			       $k =~ s/^://;
 			       $v =~ s/\n/ /g;
 			       push(@h, $k, $v);
 			   });
@@ -192,7 +193,7 @@ sub request
 	    }
 	}
 	elsif ($clen) {
-	    warn "Content-Length set when there is not content, fixed";
+	    warn "Content-Length set when there is no content, fixed";
 	    hlist_remove(\@h, 'Content-Length');
 	}
     }
